summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorKonstantin Ritt <ritt.ks@gmail.com>2015-02-12 08:30:35 +0400
committerKonstantin Ritt <ritt.ks@gmail.com>2015-02-12 07:31:18 +0000
commit86db658eace4dc84c1d3185c71f2282278b3a452 (patch)
tree63ac96c440ed67900ae461340fe5000be442e644
parentc44db2f3bd523f8547a0d23a20f48ee517f95ff0 (diff)
Do not mention QtOrganizer in QtContacts module
A fixup for 86aa56275c33be673f60f3c2b51d4f719de9315c Change-Id: Ife24e013231b81c11437d3a1268d1b6de4be93fd Reviewed-by: Matthew Vogt <matthew.vogt@qinetic.com.au>
-rw-r--r--src/contacts/filters/qcontactcollectionfilter.h2
-rw-r--r--src/contacts/filters/qcontactcollectionfilter_p.h2
-rw-r--r--src/contacts/qcontactcollection.cpp4
-rw-r--r--src/contacts/qcontactcollection.h2
-rw-r--r--src/contacts/qcontactcollection_p.h2
-rw-r--r--src/contacts/qcontactcollectionchangeset.cpp6
-rw-r--r--src/contacts/qcontactcollectionchangeset.h2
-rw-r--r--src/contacts/qcontactcollectionchangeset_p.h2
-rw-r--r--src/contacts/qcontactcollectionid.cpp4
-rw-r--r--src/contacts/qcontactcollectionid.h2
-rw-r--r--src/contacts/requests/qcontactcollectionfetchrequest.cpp2
-rw-r--r--src/contacts/requests/qcontactcollectionfetchrequest.h2
-rw-r--r--src/contacts/requests/qcontactcollectionremoverequest.cpp2
-rw-r--r--src/contacts/requests/qcontactcollectionremoverequest.h4
-rw-r--r--src/contacts/requests/qcontactcollectionsaverequest.cpp2
-rw-r--r--src/contacts/requests/qcontactcollectionsaverequest.h2
-rw-r--r--src/imports/contacts/qdeclarativecontactcollection.cpp2
-rw-r--r--tests/auto/contacts/qcontactcollection/tst_qcontactcollection.cpp6
18 files changed, 25 insertions, 25 deletions
diff --git a/src/contacts/filters/qcontactcollectionfilter.h b/src/contacts/filters/qcontactcollectionfilter.h
index da6cdede4..e31b49ff5 100644
--- a/src/contacts/filters/qcontactcollectionfilter.h
+++ b/src/contacts/filters/qcontactcollectionfilter.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/filters/qcontactcollectionfilter_p.h b/src/contacts/filters/qcontactcollectionfilter_p.h
index db06be826..c02856f8f 100644
--- a/src/contacts/filters/qcontactcollectionfilter_p.h
+++ b/src/contacts/filters/qcontactcollectionfilter_p.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/qcontactcollection.cpp b/src/contacts/qcontactcollection.cpp
index 3d7affe56..6b0854dcc 100644
--- a/src/contacts/qcontactcollection.cpp
+++ b/src/contacts/qcontactcollection.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -278,7 +278,7 @@ QDataStream &operator<<(QDataStream &out, const QContactCollection &collection)
/*!
\relates QContactCollection
- Reads an organizer collection from stream \a in into \a collection.
+ Reads a contact collection from stream \a in into \a collection.
*/
QDataStream &operator>>(QDataStream &in, QContactCollection &collection)
{
diff --git a/src/contacts/qcontactcollection.h b/src/contacts/qcontactcollection.h
index 2278db565..1b78011ed 100644
--- a/src/contacts/qcontactcollection.h
+++ b/src/contacts/qcontactcollection.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/qcontactcollection_p.h b/src/contacts/qcontactcollection_p.h
index eaf5da748..3af501551 100644
--- a/src/contacts/qcontactcollection_p.h
+++ b/src/contacts/qcontactcollection_p.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/qcontactcollectionchangeset.cpp b/src/contacts/qcontactcollectionchangeset.cpp
index 8f9af6805..fa0561bf0 100644
--- a/src/contacts/qcontactcollectionchangeset.cpp
+++ b/src/contacts/qcontactcollectionchangeset.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -223,7 +223,7 @@ void QContactCollectionChangeSet::clearRemovedCollections()
}
/*!
- Returns the list of ids of organizer collections which have been added, changed or removed from
+ Returns the list of ids of contact collections which have been added, changed or removed from
the database. The list includes information about which database operation was done. The ids and
operations are ordered so that the first operation is first in the list.
*/
@@ -233,7 +233,7 @@ QList<QPair<QContactCollectionId, QContactManager::Operation> > QContactCollecti
}
/*!
- Clears the list of ids of organizer collections which have been added, changed or removed from the database
+ Clears the list of ids of contact collections which have been added, changed or removed from the database
*/
void QContactCollectionChangeSet::clearModifiedCollections()
{
diff --git a/src/contacts/qcontactcollectionchangeset.h b/src/contacts/qcontactcollectionchangeset.h
index 8cb392cd8..fdd9df8f2 100644
--- a/src/contacts/qcontactcollectionchangeset.h
+++ b/src/contacts/qcontactcollectionchangeset.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/qcontactcollectionchangeset_p.h b/src/contacts/qcontactcollectionchangeset_p.h
index b8e372f37..bedc623c8 100644
--- a/src/contacts/qcontactcollectionchangeset_p.h
+++ b/src/contacts/qcontactcollectionchangeset_p.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/qcontactcollectionid.h b/src/contacts/qcontactcollectionid.h
index 8df821091..b559f5378 100644
--- a/src/contacts/qcontactcollectionid.h
+++ b/src/contacts/qcontactcollectionid.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/requests/qcontactcollectionfetchrequest.cpp b/src/contacts/requests/qcontactcollectionfetchrequest.cpp
index adf09a6a3..9cb6b9f70 100644
--- a/src/contacts/requests/qcontactcollectionfetchrequest.cpp
+++ b/src/contacts/requests/qcontactcollectionfetchrequest.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/requests/qcontactcollectionfetchrequest.h b/src/contacts/requests/qcontactcollectionfetchrequest.h
index db08499f5..c9fda8e9f 100644
--- a/src/contacts/requests/qcontactcollectionfetchrequest.h
+++ b/src/contacts/requests/qcontactcollectionfetchrequest.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/requests/qcontactcollectionremoverequest.cpp b/src/contacts/requests/qcontactcollectionremoverequest.cpp
index 9bd3a03ad..6ce476f14 100644
--- a/src/contacts/requests/qcontactcollectionremoverequest.cpp
+++ b/src/contacts/requests/qcontactcollectionremoverequest.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/requests/qcontactcollectionremoverequest.h b/src/contacts/requests/qcontactcollectionremoverequest.h
index 54b2e7538..0584db19d 100644
--- a/src/contacts/requests/qcontactcollectionremoverequest.h
+++ b/src/contacts/requests/qcontactcollectionremoverequest.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -71,7 +71,7 @@ public:
private:
Q_DISABLE_COPY(QContactCollectionRemoveRequest)
- friend class QOrganizerManagerEngine;
+ friend class QtContactManagerEngine;
Q_DECLARE_PRIVATE_D(d_ptr, QContactCollectionRemoveRequest)
};
diff --git a/src/contacts/requests/qcontactcollectionsaverequest.cpp b/src/contacts/requests/qcontactcollectionsaverequest.cpp
index 39877f7c9..57005eb23 100644
--- a/src/contacts/requests/qcontactcollectionsaverequest.cpp
+++ b/src/contacts/requests/qcontactcollectionsaverequest.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/contacts/requests/qcontactcollectionsaverequest.h b/src/contacts/requests/qcontactcollectionsaverequest.h
index 287157c5e..0f86e6d7e 100644
--- a/src/contacts/requests/qcontactcollectionsaverequest.h
+++ b/src/contacts/requests/qcontactcollectionsaverequest.h
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/imports/contacts/qdeclarativecontactcollection.cpp b/src/imports/contacts/qdeclarativecontactcollection.cpp
index 6505f3820..b5a687e26 100644
--- a/src/imports/contacts/qdeclarativecontactcollection.cpp
+++ b/src/imports/contacts/qdeclarativecontactcollection.cpp
@@ -48,7 +48,7 @@ QT_BEGIN_NAMESPACE
/*!
\qmltype Collection
\instantiates QDeclarativeContactCollection
- \brief The Collection element represents a collection of items in an organizer manager.
+ \brief The Collection element represents a collection of items in a contacts manager.
\ingroup qml-contacts-main
\inqmlmodule QtContacts
*/
diff --git a/tests/auto/contacts/qcontactcollection/tst_qcontactcollection.cpp b/tests/auto/contacts/qcontactcollection/tst_qcontactcollection.cpp
index d36f36c48..68895867b 100644
--- a/tests/auto/contacts/qcontactcollection/tst_qcontactcollection.cpp
+++ b/tests/auto/contacts/qcontactcollection/tst_qcontactcollection.cpp
@@ -253,13 +253,13 @@ void tst_QContactCollection::idStringFunctions()
rebuiltid = QContactCollectionId::fromString(prebuiltidstring);
QVERIFY(rebuiltid == QContactCollectionId()); // invalid so should be null.
- // this string misses the prefix (qtorganizer)
- prebuiltidstring = QString("notorganizer") + QString(":") + QString("a") + QString("::") + localId2.toHex();
+ // this string misses the prefix (qtcontacts)
+ prebuiltidstring = QString("notcontacts") + QString(":") + QString("a") + QString("::") + localId2.toHex();
rebuiltid = QContactCollectionId::fromString(prebuiltidstring);
QVERIFY(rebuiltid == QContactCollectionId()); // invalid so should be null.
// this string misses the manager uri
- prebuiltidstring = QString("notorganizer") + QString(":::") + localId2.toHex();
+ prebuiltidstring = QString("notcontacts") + QString(":::") + localId2.toHex();
rebuiltid = QContactCollectionId::fromString(prebuiltidstring);
QVERIFY(rebuiltid == QContactCollectionId()); // invalid so should be null.
}
diff --git a/src/contacts/qcontactcollectionid.cpp b/src/contacts/qcontactcollectionid.cpp
index 82b4f9243..df415528b 100644
--- a/src/contacts/qcontactcollectionid.cpp
+++ b/src/contacts/qcontactcollectionid.cpp
@@ -4,7 +4,7 @@
** Copyright (C) 2015 Canonical Ltd
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtOrganizer module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -155,7 +155,7 @@ QT_BEGIN_NAMESPACE_CONTACTS
/*!
Serializes the collection ID to a string. The format of the string will be:
- "qtorganizer:managerName:params:localId", where localId is encoded binary data
+ "qtcontacts:managerName:params:localId", where localId is encoded binary data
formatted as hexadecimal to ensure it is in a printable form.
\sa fromString(), toByteArray()
@@ -4,7 +4,7 @@
** Contact: http://www.qt-project.org/legal
**
-** This file is part of the QtOrganizer module of the Qt Toolkit.
+** This file is part of the QtContacts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$